package RPM::Source::Transformation::Factory::AddGearRemotes;

use strict;
use warnings;

use Cwd qw/cwd abs_path/;
use RPM::Source::Transformation::EarlyResource::GearRules;
use RPM::Source::Transformation::Resource::FlagLoader;
use RPM::Source::Transformation::Factory;
our @ISA=qw/RPM::Source::Transformation::Factory/;
push @RPM::Source::TransformContainer::FACTORY_CLASSES, __PACKAGE__;

our $verbose=0;

&RPM::Source::Transformation::Resource::FlagLoader::register_flagdb('gear/upstream-remotes.txt',FLAG_RESOURCE_LIST_AS_ONE2ONE);

sub transformations {
    return 
	RPM::Source::Transformation::OptHandlerWrapper->new(
	    # do not rush; wait for name resource to be properly initialized
	    -priority => PRIORITY_PRERELEASE,
	    -name => 'add-gear-upstream-remotes',
	    -description => 'add .gear/upstream/remotes from flags/gear/upstream-remotes.txt',
	    -opt_handler_sub=>\&opt_handler),
	;
}

sub opt_handler {
    my (undef,$spec,undef,$converter_opt,$resourceobj)=@_;
    my $geardir=$spec->{GEARDIR};
    return RPM::Source::TransformContainer::TRANSFORMATION_OK unless defined $geardir;
    my $remote_url=$resourceobj->get_flagdb('gear/upstream-remotes.txt');
    if ($remote_url && ! -e '.gear/upstream/remotes') {
	my $curdir=cwd;
	chdir $geardir;
	my $rules=$resourceobj->get_cached_gear_rules();
	if (not $rules->has_external_commits()) {
	    warn "WARNING: AddGearRemotes: external commits not found, won't create .gear/upstream/remotes.\n";
	} else {
	    &gear_create_remotes($remote_url);
	    # It is unsafe to have side effects.
	    # let the writer do this if it needs it.
	    # &__run(qw/gear-remotes-restore/) if -e '.gear/upstream/remotes';
	}
	chdir $curdir;
    }
    return RPM::Source::TransformContainer::TRANSFORMATION_OK;
}

sub gear_create_remotes {
    my ($url)=@_;
    &__run('gear-remotes-set-from-url', $url);
    &__run(qw!git commit -m!,"added gear upstream remotes",'.gear/upstream/remotes');
}

sub __run {
    print STDERR "running: ", join(' ',@_),"\n";
    system(@_)==0 or die "command failed: ".join(' ',@_);
}

1;
__END__
