package RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::InSRPM;

use strict;
use warnings;
use Cwd qw/abs_path cwd/;

use Source::Shared::FindMirror::ALTLinux;
use Source::Repository::RPM::ALTLinuxSrcList;
use RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch;
use RPM::Source::Transformation::RPMEditorProvider;
use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;
$RPM::Source::TransformContainer::Name2SpecProvider=__PACKAGE__;
$RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch::SRPM_NAME2SPEC_PROVIDER=__PACKAGE__;

use RPM::Source::Transformation::Component::GirarNMU::Options qw/$outsrpmdir/;
our $verbose=0;
my $repository_obj;

sub process_options {
    my ($class)=@_;
    if (not -d $outsrpmdir) {
	print STDERR "$outsrpmdir directory not found.
$0 should run on the already created directory tree.\n";
	$class->usage();
	exit 1;
    }
    if ($RPM::Source::Transformation::Component::GirarNMU::Options::opt_use_named_subtree_srpms) {
	$repository_obj=Source::Repository::RPM::ALTLinuxSrcList->create_repo_chain_from_cli(-path=>[$outsrpmdir]);
    }
}

sub name2spec {
    my (undef,$name,$converter_opt)=@_;
    my $rpmfile;
    if ($RPM::Source::Transformation::Component::GirarNMU::Options::opt_use_named_subtree_srpms) {
	my $namedir=$outsrpmdir.'/'.$name;
	die "Provider::Name2Spec: name dir $namedir not found for $name.\n" unless -d $namedir;
	my @rpmfiles=glob($namedir.'/*');
	die 'Provider::Name2Spec: file not found in ',$namedir, "\n" if @rpmfiles==0;
	die 'Provider::Name2Spec: found more than one file in ',$namedir, ': ',join(' ',@rpmfiles),"\n" if @rpmfiles>1;
	$rpmfile=$rpmfiles[0];
    } else {
	my $pkg=$repository_obj->name2pkg($name);
	die "Provider::Name2Spec: source rpm file not found for $name.\n" unless $pkg;
	$rpmfile=$pkg->file;
    }
    if ($rpmfile=~m!(^|/)((?:[^/]+)-(?:[^/-]+)-(?:[^/-]+))\.src.rpm$!) {
        $converter_opt->{-name2spec_provided_nvr}=$1;
    }
    return $RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec([SOURCERPM=>$rpmfile]);
}

1;
