package RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::OutSRPM;

use strict;
use warnings;
use Cwd qw/abs_path cwd/;

use Source::Shared::FindMirror::ALTLinux;
use Source::Repository::RPM::ALTLinuxSrcList;
use RPM::Source::Transformation::Component::InputNameCommon;
use RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch;
use RPM::Source::Transformation::RPMEditorProvider;
use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;
$RPM::Source::TransformContainer::Name2SpecProvider=__PACKAGE__;
$RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch::SRPM_NAME2SPEC_PROVIDER=__PACKAGE__;

use RPM::Source::Transformation::Component::GirarNMU::Options qw/$origin_repo/;
our $verbose=0;
my $repository_obj;
my @srpmdir;

sub print_longopt {
    print "  Name2Spec GirarNMU OutSRPM resolver input options:
    --indir|srpmdir|input-srpm-dir /path to srpms (optional)
";
}
our @LONGOPT=(
    "indir|input-srpm-dir|srpmdir=s"   => \@srpmdir,
    );

sub process_options {
    my @inpath=map {abs_path($_)} @srpmdir;
    unless (@inpath) {
	@inpath=&Source::Shared::FindMirror::ALTLinux::get_repo(
	-branch => $origin_repo,
	-prepend_hasher => 0,
	-prepend_path => undef,
	-append_repository_chain => 0,
	-verbose => ($verbose || $Source::Shared::verbose),
	);
    }
    $repository_obj=Source::Repository::RPM::ALTLinuxSrcList->create_repo_chain_from_cli(-path=>\@inpath);
}

sub name2spec {
    my (undef,$name,$converter_opt)=@_;
    my $pkg=$repository_obj->name2pkg($name);
    die "Provider::Name2Spec: source rpm file not found for $name.\n" unless $pkg;
    my $rpmfile=$pkg->file;
    if ($rpmfile=~m!(^|/)((?:[^/]+)-(?:[^/-]+)-(?:[^/-]+))\.src.rpm$!) {
        $converter_opt->{-name2spec_provided_nvr}=$1;
    }
    return $RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec([SOURCERPM=>$rpmfile]);
}

1;
